@@ -22,6 +22,7 @@ import (
 	_ "github.com/iawia002/lux/extractors/pixivision"
 	_ "github.com/iawia002/lux/extractors/pornhub"
 	_ "github.com/iawia002/lux/extractors/qq"
+	_ "github.com/iawia002/lux/extractors/reddit"
 	_ "github.com/iawia002/lux/extractors/streamtape"
 	_ "github.com/iawia002/lux/extractors/tangdou"
 	_ "github.com/iawia002/lux/extractors/tiktok"
@@ -30,6 +31,7 @@ import (
 	_ "github.com/iawia002/lux/extractors/udn"
 	_ "github.com/iawia002/lux/extractors/universal"
 	_ "github.com/iawia002/lux/extractors/vimeo"
+	_ "github.com/iawia002/lux/extractors/vk"
 	_ "github.com/iawia002/lux/extractors/weibo"
 	_ "github.com/iawia002/lux/extractors/ximalaya"
 	_ "github.com/iawia002/lux/extractors/xinpianchang"
