@@ -2,8 +2,10 @@ package youtube
 
 import (
 	"fmt"
+	"net/http"
 	"strconv"
 
+	"github.com/iawia002/pandora/array"
 	"github.com/kkdai/youtube/v2"
 	"github.com/pkg/errors"
 
@@ -27,7 +29,13 @@ type extractor struct {
 // New returns a youtube extractor.
 func New() extractors.Extractor {
 	return &extractor{
-		client: &youtube.Client{},
+		client: &youtube.Client{
+			HTTPClient: &http.Client{
+				Transport: &http.Transport{
+					Proxy: http.ProxyFromEnvironment,
+				},
+			},
+		},
 	}
 }
 
@@ -51,7 +59,7 @@ func (e *extractor) Extract(url string, option extractors.Options) ([]*extractor
 	wgp := utils.NewWaitGroupPool(option.ThreadNumber)
 	dataIndex := 0
 	for index, videoEntry := range playlist.Videos {
-		if !utils.ItemInSlice(index+1, needDownloadItems) {
+		if !array.ItemInArray(index+1, needDownloadItems) {
 			continue
 		}
 
